@@ -40,6 +40,6 @@ from LivestockCV.core import bbox_to_bytes
 from LivestockCV.core import take_photo
 from LivestockCV.core.show_image import show_image
 from LivestockCV.core.CalculateAngle import calculate_Angle
-from LivestockCV.core._dimensions import Dimensions
+from LivestockCV.core._dimensions import _dimensions
 
 
